"""
Interfaces for ingest_envoy
"""
import abc
from abc import ABC

from ingest_envoy.schema import AbstractTextFile


class IngestLauncherIF(ABC):
    """
    Generic Ingestion Launcher methods.
    Should be implemented for any type of ingestion launcher
    """

    # launch all ingest steps, should be called in ingest.main
    @abc.abstractmethod
    def launch_ingestion(self):
        pass

    # setup workflow results for ingestion, ensure placement in staging area
    @abc.abstractmethod
    def prepare_for_ingest(self):
        pass

    # create ingestion manifest
    @abc.abstractmethod
    def create_manifest(self, additional_file: AbstractTextFile = None):
        pass
